==> openttd-1.9.0-beta1-docs.tar.tar: openttd-1.9.0-beta1-docs/html/d0/d02/news__widget_8h.js <==
var news__widget_8h =
[
    [ "MessageHistoryWidgets", "d0/d02/news__widget_8h.html#a4e3c19ea12ce23112f309a4261c6ad62", [
      [ "WID_MH_STICKYBOX", "d0/d02/news__widget_8h.html#a4e3c19ea12ce23112f309a4261c6ad62a73a1efd39cd9c57692e21d8a26daf9bc", null ],
      [ "WID_MH_BACKGROUND", "d0/d02/news__widget_8h.html#a4e3c19ea12ce23112f309a4261c6ad62aea19aa02e1358cd138feeeb99a9b7ccd", null ],
      [ "WID_MH_SCROLLBAR", "d0/d02/news__widget_8h.html#a4e3c19ea12ce23112f309a4261c6ad62a8e7d31f00ff9144225e2fef3670d05d5", null ]
    ] ],
    [ "NewsWidgets", "d0/d02/news__widget_8h.html#ab90d57137412d0cfb8180bd50c50d7e7", [
      [ "WID_N_PANEL", "d0/d02/news__widget_8h.html#ab90d57137412d0cfb8180bd50c50d7e7a4e7d6129b86ea8bf12a78cb005903d87", null ],
      [ "WID_N_TITLE", "d0/d02/news__widget_8h.html#ab90d57137412d0cfb8180bd50c50d7e7abb090cf5e72cf07cdd066cb7bf30f342", null ],
      [ "WID_N_HEADLINE", "d0/d02/news__widget_8h.html#ab90d57137412d0cfb8180bd50c50d7e7a93d39dcc843ea4422b320130f45792fc", null ],
      [ "WID_N_CLOSEBOX", "d0/d02/news__widget_8h.html#ab90d57137412d0cfb8180bd50c50d7e7a7dc2f908cf02e4a976c46dabe2876185", null ],
      [ "WID_N_DATE", "d0/d02/news__widget_8h.html#ab90d57137412d0cfb8180bd50c50d7e7a38a7ce53580664ba7e99aa0af162efd2", null ],
      [ "WID_N_CAPTION", "d0/d02/news__widget_8h.html#ab90d57137412d0cfb8180bd50c50d7e7a93addd56ece62a7869d7b36abfe14333", null ],
      [ "WID_N_INSET", "d0/d02/news__widget_8h.html#ab90d57137412d0cfb8180bd50c50d7e7a9665061091398473a58994c15fae7f3d", null ],
      [ "WID_N_VIEWPORT", "d0/d02/news__widget_8h.html#ab90d57137412d0cfb8180bd50c50d7e7ac2a3f030f40facfd770900951c41f0c4", null ],
      [ "WID_N_COMPANY_MSG", "d0/d02/news__widget_8h.html#ab90d57137412d0cfb8180bd50c50d7e7aee3166c3f43ada35c39f4dd9b67dbfd6", null ],
      [ "WID_N_MESSAGE", "d0/d02/news__widget_8h.html#ab90d57137412d0cfb8180bd50c50d7e7ad67f05d98d895ef2d1d3b5d788b5a33c", null ],
      [ "WID_N_MGR_FACE", "d0/d02/news__widget_8h.html#ab90d57137412d0cfb8180bd50c50d7e7ad23c17e1be41d9efc7158919875fa491", null ],
      [ "WID_N_MGR_NAME", "d0/d02/news__widget_8h.html#ab90d57137412d0cfb8180bd50c50d7e7af6ff3323e87591cbe9e259ca938db4f7", null ],
      [ "WID_N_VEH_TITLE", "d0/d02/news__widget_8h.html#ab90d57137412d0cfb8180bd50c50d7e7ab9202f25c5145acab32ffff574dfc1f1", null ],
      [ "WID_N_VEH_BKGND", "d0/d02/news__widget_8h.html#ab90d57137412d0cfb8180bd50c50d7e7ae023496193f34eff765576e542558351", null ],
      [ "WID_N_VEH_NAME", "d0/d02/news__widget_8h.html#ab90d57137412d0cfb8180bd50c50d7e7aee2301a19f4f24211acfca760c3e1aa3", null ],
      [ "WID_N_VEH_SPR", "d0/d02/news__widget_8h.html#ab90d57137412d0cfb8180bd50c50d7e7aebd91ed9d005cba7a603565175c9ce84", null ],
      [ "WID_N_VEH_INFO", "d0/d02/news__widget_8h.html#ab90d57137412d0cfb8180bd50c50d7e7ab9db1c3370f81b02225e66d912c47ca4", null ]
    ] ]
];

==> openttd-1.11.0-beta1-docs.tar.tar: openttd-1.11.0-beta1-docs/html/d0/d02/news__widget_8h.js <==
var news__widget_8h =
[
    [ "MessageHistoryWidgets", "d0/d02/news__widget_8h.html#a4e3c19ea12ce23112f309a4261c6ad62", [
      [ "WID_MH_STICKYBOX", "d0/d02/news__widget_8h.html#a4e3c19ea12ce23112f309a4261c6ad62a73a1efd39cd9c57692e21d8a26daf9bc", null ],
      [ "WID_MH_BACKGROUND", "d0/d02/news__widget_8h.html#a4e3c19ea12ce23112f309a4261c6ad62aea19aa02e1358cd138feeeb99a9b7ccd", null ],
      [ "WID_MH_SCROLLBAR", "d0/d02/news__widget_8h.html#a4e3c19ea12ce23112f309a4261c6ad62a8e7d31f00ff9144225e2fef3670d05d5", null ]
    ] ],
    [ "NewsWidgets", "d0/d02/news__widget_8h.html#ab90d57137412d0cfb8180bd50c50d7e7", [
      [ "WID_N_PANEL", "d0/d02/news__widget_8h.html#ab90d57137412d0cfb8180bd50c50d7e7a4e7d6129b86ea8bf12a78cb005903d87", null ],
      [ "WID_N_TITLE", "d0/d02/news__widget_8h.html#ab90d57137412d0cfb8180bd50c50d7e7abb090cf5e72cf07cdd066cb7bf30f342", null ],
      [ "WID_N_HEADLINE", "d0/d02/news__widget_8h.html#ab90d57137412d0cfb8180bd50c50d7e7a93d39dcc843ea4422b320130f45792fc", null ],
      [ "WID_N_CLOSEBOX", "d0/d02/news__widget_8h.html#ab90d57137412d0cfb8180bd50c50d7e7a7dc2f908cf02e4a976c46dabe2876185", null ],
      [ "WID_N_DATE", "d0/d02/news__widget_8h.html#ab90d57137412d0cfb8180bd50c50d7e7a38a7ce53580664ba7e99aa0af162efd2", null ],
      [ "WID_N_CAPTION", "d0/d02/news__widget_8h.html#ab90d57137412d0cfb8180bd50c50d7e7a93addd56ece62a7869d7b36abfe14333", null ],
      [ "WID_N_INSET", "d0/d02/news__widget_8h.html#ab90d57137412d0cfb8180bd50c50d7e7a9665061091398473a58994c15fae7f3d", null ],
      [ "WID_N_VIEWPORT", "d0/d02/news__widget_8h.html#ab90d57137412d0cfb8180bd50c50d7e7ac2a3f030f40facfd770900951c41f0c4", null ],
      [ "WID_N_COMPANY_MSG", "d0/d02/news__widget_8h.html#ab90d57137412d0cfb8180bd50c50d7e7aee3166c3f43ada35c39f4dd9b67dbfd6", null ],
      [ "WID_N_MESSAGE", "d0/d02/news__widget_8h.html#ab90d57137412d0cfb8180bd50c50d7e7ad67f05d98d895ef2d1d3b5d788b5a33c", null ],
      [ "WID_N_MGR_FACE", "d0/d02/news__widget_8h.html#ab90d57137412d0cfb8180bd50c50d7e7ad23c17e1be41d9efc7158919875fa491", null ],
      [ "WID_N_MGR_NAME", "d0/d02/news__widget_8h.html#ab90d57137412d0cfb8180bd50c50d7e7af6ff3323e87591cbe9e259ca938db4f7", null ],
      [ "WID_N_VEH_TITLE", "d0/d02/news__widget_8h.html#ab90d57137412d0cfb8180bd50c50d7e7ab9202f25c5145acab32ffff574dfc1f1", null ],
      [ "WID_N_VEH_BKGND", "d0/d02/news__widget_8h.html#ab90d57137412d0cfb8180bd50c50d7e7ae023496193f34eff765576e542558351", null ],
      [ "WID_N_VEH_NAME", "d0/d02/news__widget_8h.html#ab90d57137412d0cfb8180bd50c50d7e7aee2301a19f4f24211acfca760c3e1aa3", null ],
      [ "WID_N_VEH_SPR", "d0/d02/news__widget_8h.html#ab90d57137412d0cfb8180bd50c50d7e7aebd91ed9d005cba7a603565175c9ce84", null ],
      [ "WID_N_VEH_INFO", "d0/d02/news__widget_8h.html#ab90d57137412d0cfb8180bd50c50d7e7ab9db1c3370f81b02225e66d912c47ca4", null ],
      [ "WID_N_SHOW_GROUP", "d0/d02/news__widget_8h.html#ab90d57137412d0cfb8180bd50c50d7e7a8270e2612edcbbf63324d25ab1cbeec4", null ]
    ] ]
];
